@@ -8,7 +8,7 @@
  * 
  *     This program is distributed in the hope that it will be useful,
  *     but WITHOUT ANY WARRANTY; without even the implied warranty of
- *     MERCHANPOILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *     GNU General Public License for more details.
  * 
  *     You should have received a copy of the GNU General Public License
@@ -383,7 +383,6 @@ motion_notify_event (GtkWidget * text_view, GdkEventMotion * event)
 
   set_cursor_if_appropriate (GTK_TEXT_VIEW (text_view), x, y);
 
-  gdk_window_get_pointer (gtk_widget_get_window (text_view), NULL, NULL, NULL);
   return FALSE;
 }
 
@@ -393,9 +392,13 @@ motion_notify_event (GtkWidget * text_view, GdkEventMotion * event)
 static gboolean
 visibility_notify_event (GtkWidget * text_view, GdkEventVisibility * event)
 {
+  GdkDeviceManager *device_manager;
+  GdkDevice *pointer;
   gint wx, wy, bx, by;
 
-  gdk_window_get_pointer (gtk_widget_get_window (text_view), &wx, &wy, NULL);
+  device_manager = gdk_display_get_device_manager (gtk_widget_get_display (text_view));
+  pointer = gdk_device_manager_get_client_pointer (device_manager);
+  gdk_window_get_device_position (gtk_widget_get_window (text_view), pointer, &wx, &wy, NULL);
 
   gtk_text_view_window_to_buffer_coords (GTK_TEXT_VIEW (text_view),
                                          GTK_TEXT_WINDOW_WIDGET,
