@@ -64,7 +64,6 @@ struct _GtrPreferencesDialogPrivate
 
   /* Files->General */
   GtkWidget *warn_if_contains_fuzzy_checkbutton;
-  GtkWidget *delete_compiled_checkbutton;
 
   /* Files->Autosave */
   GtkWidget *autosave_checkbutton;
@@ -111,11 +110,6 @@ setup_files_general_page (GtrPreferencesDialog * dlg)
                    dlg->priv->warn_if_contains_fuzzy_checkbutton,
                    "active",
                    G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
-  g_settings_bind (dlg->priv->files_settings,
-                   GTR_SETTINGS_DELETE_COMPILED,
-                   dlg->priv->delete_compiled_checkbutton,
-                   "active",
-                   G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
 }
 
 static void
@@ -671,8 +665,6 @@ gtr_preferences_dialog_init (GtrPreferencesDialog * dlg)
                                   "warn_if_fuzzy_checkbutton",
                                   &dlg->
                                   priv->warn_if_contains_fuzzy_checkbutton,
-                                  "delete_compiled_checkbutton",
-                                  &dlg->priv->delete_compiled_checkbutton,
                                   "autosave_checkbutton",
                                   &dlg->priv->autosave_checkbutton,
                                   "autosave_interval_spinbutton",
@@ -718,12 +710,12 @@ gtr_preferences_dialog_init (GtrPreferencesDialog * dlg)
 
   gtk_container_set_border_width (GTK_CONTAINER (dlg->priv->notebook), 5);
 
-  context = gtk_widget_get_style_context (profiles_toolbar);
-  gtk_style_context_set_junction_sides (context, GTK_JUNCTION_TOP);
-
   context = gtk_widget_get_style_context (profiles_scrolled_window);
   gtk_style_context_set_junction_sides (context, GTK_JUNCTION_BOTTOM);
 
+  context = gtk_widget_get_style_context (profiles_toolbar);
+  gtk_style_context_set_junction_sides (context, GTK_JUNCTION_TOP);
+
   setup_files_pages (dlg);
   setup_editor_pages (dlg);
   setup_profile_pages (dlg);
