@@ -201,8 +201,10 @@ gtr_header_new (po_message_iterator_t iter, po_message_t message)
 {
   GtrHeader *header;
 
-  header = g_object_new (GTR_TYPE_HEADER, "gettext-iter", iter,
-                         "gettext-msg", message, NULL);
+  header = g_object_new (GTR_TYPE_HEADER, NULL);
+
+  _gtr_msg_set_iterator (GTR_MSG (header), iter);
+  _gtr_msg_set_message (GTR_MSG (header), message);
 
   /* We have to parse the number of plurals */
   parse_nplurals (header);
@@ -223,7 +225,7 @@ gtr_header_get_comments (GtrHeader * header)
 {
   g_return_val_if_fail (GTR_IS_HEADER (header), NULL);
 
-  return po_message_comments (gtr_msg_get_message (GTR_MSG (header)));
+  return po_message_comments (_gtr_msg_get_message (GTR_MSG (header)));
 }
 
 void
@@ -232,7 +234,7 @@ gtr_header_set_comments (GtrHeader * header, const gchar * comments)
   g_return_if_fail (GTR_IS_HEADER (header));
   g_return_if_fail (comments != NULL);
 
-  po_message_set_comments (gtr_msg_get_message (GTR_MSG (header)), comments);
+  po_message_set_comments (_gtr_msg_get_message (GTR_MSG (header)), comments);
 }
 
 gchar *
